==> zio-aws-ec2_2.13-5.17.124.3-sources.jar: zio/aws/ec2/model/ModifyDefaultCreditSpecificationRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class ModifyDefaultCreditSpecificationRequest(
    instanceFamily: zio.aws.ec2.model.UnlimitedSupportedInstanceFamily,
    cpuCredits: String
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyDefaultCreditSpecificationRequest = {
    import ModifyDefaultCreditSpecificationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyDefaultCreditSpecificationRequest
      .builder()
      .instanceFamily(instanceFamily.unwrap)
      .cpuCredits(cpuCredits: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ModifyDefaultCreditSpecificationRequest.ReadOnly =
    zio.aws.ec2.model.ModifyDefaultCreditSpecificationRequest
      .wrap(buildAwsValue())
}
object ModifyDefaultCreditSpecificationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyDefaultCreditSpecificationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyDefaultCreditSpecificationRequest =
      zio.aws.ec2.model
        .ModifyDefaultCreditSpecificationRequest(instanceFamily, cpuCredits)
    def instanceFamily: zio.aws.ec2.model.UnlimitedSupportedInstanceFamily
    def cpuCredits: String
    def getInstanceFamily: ZIO[
      Any,
      Nothing,
      zio.aws.ec2.model.UnlimitedSupportedInstanceFamily
    ] = ZIO.succeed(instanceFamily)
    def getCpuCredits: ZIO[Any, Nothing, String] = ZIO.succeed(cpuCredits)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyDefaultCreditSpecificationRequest
  ) extends zio.aws.ec2.model.ModifyDefaultCreditSpecificationRequest.ReadOnly {
    override val instanceFamily
        : zio.aws.ec2.model.UnlimitedSupportedInstanceFamily =
      zio.aws.ec2.model.UnlimitedSupportedInstanceFamily
        .wrap(impl.instanceFamily())
    override val cpuCredits: String = impl.cpuCredits(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyDefaultCreditSpecificationRequest
  ): zio.aws.ec2.model.ModifyDefaultCreditSpecificationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-7.21.15.12-sources.jar: zio/aws/ec2/model/ModifyDefaultCreditSpecificationRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyDefaultCreditSpecificationRequest(
    dryRun: Optional[Boolean] = Optional.Absent,
    instanceFamily: zio.aws.ec2.model.UnlimitedSupportedInstanceFamily,
    cpuCredits: String
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyDefaultCreditSpecificationRequest = {
    import ModifyDefaultCreditSpecificationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyDefaultCreditSpecificationRequest
      .builder()
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .instanceFamily(instanceFamily.unwrap)
      .cpuCredits(cpuCredits: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ModifyDefaultCreditSpecificationRequest.ReadOnly =
    zio.aws.ec2.model.ModifyDefaultCreditSpecificationRequest
      .wrap(buildAwsValue())
}
object ModifyDefaultCreditSpecificationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyDefaultCreditSpecificationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyDefaultCreditSpecificationRequest =
      zio.aws.ec2.model.ModifyDefaultCreditSpecificationRequest(
        dryRun.map(value => value),
        instanceFamily,
        cpuCredits
      )
    def dryRun: Optional[Boolean]
    def instanceFamily: zio.aws.ec2.model.UnlimitedSupportedInstanceFamily
    def cpuCredits: String
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getInstanceFamily: ZIO[
      Any,
      Nothing,
      zio.aws.ec2.model.UnlimitedSupportedInstanceFamily
    ] = ZIO.succeed(instanceFamily)
    def getCpuCredits: ZIO[Any, Nothing, String] = ZIO.succeed(cpuCredits)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyDefaultCreditSpecificationRequest
  ) extends zio.aws.ec2.model.ModifyDefaultCreditSpecificationRequest.ReadOnly {
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val instanceFamily
        : zio.aws.ec2.model.UnlimitedSupportedInstanceFamily =
      zio.aws.ec2.model.UnlimitedSupportedInstanceFamily
        .wrap(impl.instanceFamily())
    override val cpuCredits: String = impl.cpuCredits(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyDefaultCreditSpecificationRequest
  ): zio.aws.ec2.model.ModifyDefaultCreditSpecificationRequest.ReadOnly =
    new Wrapper(impl)
}
